methodChannel property
Underlying MethodChannel. Exposed for tests so they can install a mock handler; treat it as private otherwise.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('flutter_live2d');
Underlying MethodChannel. Exposed for tests so they can install a mock handler; treat it as private otherwise.
@visibleForTesting
final methodChannel = const MethodChannel('flutter_live2d');